@@ -211,6 +211,7 @@ class AsyncFleet:
         region: Optional[str] = None,
         env_variables: Optional[Dict[str, Any]] = None,
         image_type: Optional[str] = None,
+        ttl_seconds: Optional[int] = None,
     ) -> AsyncEnv:
         if ":" in env_key:
             env_key_part, env_version = env_key.split(":", 1)
@@ -245,6 +246,7 @@ class AsyncFleet:
             env_variables=env_variables,
             image_type=image_type,
             created_from="sdk",
+            ttl_seconds=ttl_seconds,
         )
 
         # Only use region-specific base URL if no custom base URL is set
@@ -397,6 +399,7 @@ class AsyncFleet:
             verifier_id=verifier_id,  # Set verifier_id so _rebuild_verifier works
             verifier_sha=verifier_sha,  # Set verifier_sha
             metadata=task_json.get("metadata", {}),  # Default empty metadata
+            output_json_schema=task_json.get("output_json_schema"),  # JSON schema for output
         )
         return task
 
@@ -407,6 +410,7 @@ class AsyncFleet:
         version: Optional[str] = None,
         team_id: Optional[str] = None,
         project_key: Optional[str] = None,
+        task_project_key: Optional[str] = None,
         data_id: Optional[str] = None,
         data_version: Optional[str] = None,
     ) -> List[Task]:
@@ -418,6 +422,7 @@ class AsyncFleet:
             version: Optional version to filter tasks by (client-side filter)
             team_id: Optional team_id to filter by (admin only)
             project_key: Optional project key to filter tasks by
+            task_project_key: Optional task project key to filter tasks by
             data_id: Optional data identifier to filter tasks by
             data_version: Optional data version to filter tasks by
 
@@ -433,6 +438,8 @@ class AsyncFleet:
             params["team_id"] = team_id
         if project_key is not None:
             params["project_key"] = project_key
+        if task_project_key is not None:
+            params["task_project_key"] = task_project_key
         if data_id is not None:
             params["data_id"] = data_id
         if data_version is not None:
@@ -547,6 +554,7 @@ class AsyncFleet:
                 verifier_func=verifier_func,  # Set verifier code
                 verifier=verifier,  # Use created verifier or None
                 metadata={},  # Default empty metadata
+                output_json_schema=getattr(task_response, "output_json_schema", None),  # Get output_json_schema if available
             )
             tasks.append(task)
 
@@ -700,6 +708,7 @@ class AsyncFleet:
         task_key: str,
         prompt: Optional[str] = None,
         verifier_code: Optional[str] = None,
+        metadata: Optional[Dict[str, Any]] = None,
     ) -> TaskResponse:
         """Update an existing task.
 
@@ -707,11 +716,12 @@ class AsyncFleet:
             task_key: The key of the task to update
             prompt: New prompt text for the task (optional)
             verifier_code: Python code for task verification (optional)
+            metadata: Additional metadata for the task (optional)
 
         Returns:
             TaskResponse containing the updated task details
         """
-        payload = TaskUpdateRequest(prompt=prompt, verifier_code=verifier_code)
+        payload = TaskUpdateRequest(prompt=prompt, verifier_code=verifier_code, metadata=metadata)
         response = await self.client.request(
             "PUT", f"/v1/tasks/{task_key}", json=payload.model_dump(exclude_none=True)
         )
@@ -721,12 +731,14 @@ class AsyncFleet:
         self,
         task_key: str,
         version_id: Optional[str] = None,
+        team_id: Optional[str] = None,
     ) -> TaskResponse:
         """Get a task by key and optional version.
 
         Args:
             task_key: The key of the task to retrieve
             version_id: Optional version ID to filter by
+            team_id: Optional team_id to filter by (admin only)
 
         Returns:
             TaskResponse containing the task details
@@ -734,6 +746,8 @@ class AsyncFleet:
         params = {}
         if version_id is not None:
             params["version_id"] = version_id
+        if team_id is not None:
+            params["team_id"] = team_id
 
         response = await self.client.request(
             "GET", f"/v1/tasks/{task_key}", params=params
